@@ -1,5 +1,6 @@
 #!/usr/bin/env python3
 
+from arcor2.data.object_type import Mesh
 from arcor2.object_types.upload import Urdf, upload_def, upload_whatever
 from arcor2_fit_demo import get_data
 from arcor2_fit_demo.object_types.abstract_dobot import AbstractDobot
@@ -14,7 +15,11 @@ def main() -> None:
     upload_def(AbstractDobot)
     upload_def(DobotMagician, urdf=Urdf(get_data("dobot-magician"), DobotMagician.urdf_package_name))
     upload_def(DobotM1, urdf=Urdf(get_data("dobot-m1"), DobotM1.urdf_package_name))
-    upload_def(KinectAzure)  # TODO add its mesh
+    upload_def(
+        KinectAzure,
+        Mesh(KinectAzure.__name__, KinectAzure.mesh_filename),
+        file_to_upload=get_data(KinectAzure.mesh_filename),
+    )
     upload_whatever(FitCommonMixin)
 
 
